Enum tss_esapi::abstraction::nv::NvOpenOptions
source · #[non_exhaustive]
pub enum NvOpenOptions {
NewIndex {
nv_public: NvPublic,
auth_handle: NvAuth,
},
ExistingIndex {
nv_index_handle: NvIndexTpmHandle,
auth_handle: NvAuth,
},
}Expand description
Options and flags which can be used to determine how a non-volatile storage index is opened.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NewIndex
Define a new NV space with given auth
ExistingIndex
Open the NV space at the given handle, with the given auth
Implementations
sourceimpl NvOpenOptions
impl NvOpenOptions
sourcepub fn open<'a>(&self, context: &'a mut Context) -> Result<NvReaderWriter<'a>>
pub fn open<'a>(&self, context: &'a mut Context) -> Result<NvReaderWriter<'a>>
Opens a non-volatile storage index using the options specified by self
The non-volatile storage index may be used for reading or writing or both.