EcSigner

Struct EcSigner 

pub struct EcSigner<C, Ctx>{ /* private fields */ }
EcSigner will sign a payload with an elliptic curve secret key stored on the TPM.

Parameters

Parameter C describes the curve that is of use (Nist P-256, Nist P-384, …)

use p256::NistP256;
use signature::Signer;

let key_params = EcSigner::<NistP256, ()>::key_params_default();
let (tpm_km, _tpm_auth) = context
    .create_key(key_params, 0)
    .expect("Failed to create a private keypair");

let signer = EcSigner::<NistP256,_>::new((Mutex::new(&mut context), tpm_km, key_params, None))
     .expect("Failed to create a signer");
let signature: p256::ecdsa::Signature = signer.sign(b"Hello Bob, Alice here.");

Implementations

Source

impl<C, Ctx> EcSigner<C, Ctx>

pub fn new(context: Ctx) -> Result<Self, Error>

Source

impl<C, Ctx> EcSigner<C, Ctx>

pub fn key_params_default() -> KeyParams

Key parameters for this curve, selected digest is the one selected by DigestPrimitive

pub fn key_params<D>() -> KeyParams

Key parameters for this curve

Parameters

The hashing algorithm D is the digest that will be used for signatures (SHA-256, SHA3-256, …).