AssociatedHashingAlgorithm

Trait AssociatedHashingAlgorithm 

pub trait AssociatedHashingAlgorithm {
    const TPM_DIGEST: HashingAlgorithm;
}
Provides the value of the digest used in this crate for the digest.

Required Associated Constants

const TPM_DIGEST: HashingAlgorithm

Value of the digest when interacting with the TPM.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors