Struct tss_esapi::abstraction::transient::ObjectWrapper
source · pub struct ObjectWrapper {
pub material: KeyMaterial,
pub params: KeyParams,
pub auth: Option<Auth>,
}Expand description
Structure containing all the defining elements of a TPM key
materialidentifies the numeric value of the key objectparamsidentifies the algorithm to use on the key and other relevant parametersauthidentifies the optional authentication value to be used with the key
Fields
material: KeyMaterialparams: KeyParamsauth: Option<Auth>Trait Implementations
sourceimpl Clone for ObjectWrapper
impl Clone for ObjectWrapper
sourcefn clone(&self) -> ObjectWrapper
fn clone(&self) -> ObjectWrapper
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more