Module for representation of attributes
Re-exports
pub use algorithm::AlgorithmAttributes;pub use command_code::CommandCodeAttributes;pub use locality::LocalityAttributes;pub use locality::LocalityAttributesBuilder;pub use nv_index::NvIndexAttributes;pub use nv_index::NvIndexAttributesBuilder;pub use object::ObjectAttributes;pub use object::ObjectAttributesBuilder;pub use session::SessionAttributes;pub use session::SessionAttributesBuilder;pub use session::SessionAttributesMask;
Modules
- algorithm
- command_
code - locality
- nv_
index - Representation of the attributes defined in the NV Storage -> TPMA_NV section of the specification.
- object
- Representation of the attributes defined in the Attribute structures -> TPMA_OBJECT section of the specification
- session
- Representation of the attributes defined in the Attribute structures -> TPMA_OBJECT section of the specification.