CommandCodeAttributesBuilder

Struct CommandCodeAttributesBuilder 

pub struct CommandCodeAttributesBuilder { /* private fields */ }
A builder for CommandCodeAttributes

Implementations

Source

impl CommandCodeAttributesBuilder

pub const fn new() -> Self

Creates a new command code attributes builder.

pub fn with_command_index(self, command_index: u16) -> Self

Sets the command code to the specified value in the builder.

pub fn with_nv(self, set: bool) -> Self

Sets the ‘nv’ bit in the builder.

pub fn with_extensive(self, set: bool) -> Self

Sets the ‘extensive’ bit in the builder.

pub fn with_flushed(self, set: bool) -> Self

Sets the ‘flushed’ bit in the builder.

pub fn with_c_handles(self, value: u8) -> Self

Sets the three ‘c_handles’ bits in the builder.

Details

All bits besides the three first in the provided argument will be ignored.

pub fn with_r_handle(self, set: bool) -> Self

Sets the ‘r_handle’ bit in the builder.

pub fn with_vendor_specific(self, set: bool) -> Self

Sets the ‘V’(i.e. vendor specific) bit in the builder.

pub fn build(self) -> Result<CommandCodeAttributes>

Builds the command code attributes

Errors

Returns an error if command index is not a command index associated with a CommandCode specified in the TPM specification.