pub struct NvIndexAttributes(pub TPMA_NV);
Bitfield representing the nv index attributes.

Tuple Fields

0: TPMA_NV

Implementations

Returns the NvIndexType of the NvIndexAttributes

Validates the attributes

Details

Performs checks on self in order to verify that the attributes conforms to the requirements specified in the standard.

Errors

Returns an error if some attributes are missing or are in conflict with each other.

Get a builder for the structure