pub struct ObjectAttributesBuilder { /* private fields */ }
A builder for ObjectAttributes

Implementations

source

impl ObjectAttributesBuilder

source

pub const fn new() -> Self

Creates an new ObjectAttributes builder.

source

pub fn with_fixed_tpm(self, set: bool) -> Self

Controls the fixed tpm attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_st_clear(self, set: bool) -> Self

Controls the st clear attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_fixed_parent(self, set: bool) -> Self

Controls the fixed parent attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_sensitive_data_origin(self, set: bool) -> Self

Controls the sensitive data origin attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_user_with_auth(self, set: bool) -> Self

Controls the user with auth attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_admin_with_policy(self, set: bool) -> Self

Controls the admin with policy attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_no_da(self, set: bool) -> Self

Controls the no da attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_encrypted_duplication(self, set: bool) -> Self

Controls the encrypted duplication attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_restricted(self, set: bool) -> Self

Controls the restricted attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_decrypt(self, set: bool) -> Self

Controls the decrypt attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_sign_encrypt(self, set: bool) -> Self

Controls the sign/encrypt attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn with_x509_sign(self, set: bool) -> Self

Controls the X509 sign attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.
source

pub fn build(self) -> Result<ObjectAttributes>

Builds the nv index attributes.

Errors

Returns an error if some attributes are missing or are in conflict with each other.