Module tss_esapi::constants::response_code [−][src]
Representation of the return code TSS2_RC (TPM_RC) Module for error types
This module provides the error reporting framework for the crate. Error provenience is marked as a variant of an enum, distinguishing between errors coming from the TSS stack and those generated by this crate.
Structs
| FormatOneResponseCode | |
| FormatZeroResponseCode | |
| ResponseCode |
Enums
| Tss2ResponseCode | Rust native representation of the TSS2 response codes as defined in the spec. |
| Tss2ResponseCodeKind | Rust enum representation of TSS 2 error codes. |