Struct tss_esapi::constants::response_code::FormatOneResponseCode
source · [−]pub struct FormatOneResponseCode(pub TSS2_RC);Tuple Fields
0: TSS2_RCTrait Implementations
sourceimpl<T> BitRange<T> for FormatOneResponseCode where
TSS2_RC: BitRange<T>,
impl<T> BitRange<T> for FormatOneResponseCode where
TSS2_RC: BitRange<T>,
sourceimpl Clone for FormatOneResponseCode
impl Clone for FormatOneResponseCode
sourcefn clone(&self) -> FormatOneResponseCode
fn clone(&self) -> FormatOneResponseCode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for FormatOneResponseCode
impl Debug for FormatOneResponseCode
sourceimpl Display for FormatOneResponseCode
impl Display for FormatOneResponseCode
sourceimpl Error for FormatOneResponseCode
impl Error for FormatOneResponseCode
1.30.0 · sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
The lower-level source of this error, if any. Read more
sourcefn backtrace(&self) -> Option<&Backtrace>
fn backtrace(&self) -> Option<&Backtrace>
🔬 This is a nightly-only experimental API. (
backtrace)Returns a stack backtrace, if available, of where this error occurred. Read more
1.0.0 · sourcefn description(&self) -> &str
fn description(&self) -> &str
👎 Deprecated since 1.42.0:
use the Display impl or to_string()
sourceimpl PartialEq<FormatOneResponseCode> for FormatOneResponseCode
impl PartialEq<FormatOneResponseCode> for FormatOneResponseCode
sourcefn eq(&self, other: &FormatOneResponseCode) -> bool
fn eq(&self, other: &FormatOneResponseCode) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &FormatOneResponseCode) -> bool
fn ne(&self, other: &FormatOneResponseCode) -> bool
This method tests for !=.
impl Copy for FormatOneResponseCode
impl StructuralPartialEq for FormatOneResponseCode