Struct tss_esapi::constants::response_code::FormatZeroResponseCode
source · [−]pub struct FormatZeroResponseCode(pub TSS2_RC);Tuple Fields
0: TSS2_RCTrait Implementations
sourceimpl<T> BitRange<T> for FormatZeroResponseCode where
TSS2_RC: BitRange<T>,
impl<T> BitRange<T> for FormatZeroResponseCode where
TSS2_RC: BitRange<T>,
sourceimpl Clone for FormatZeroResponseCode
impl Clone for FormatZeroResponseCode
sourcefn clone(&self) -> FormatZeroResponseCode
fn clone(&self) -> FormatZeroResponseCode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for FormatZeroResponseCode
impl Debug for FormatZeroResponseCode
sourceimpl Display for FormatZeroResponseCode
impl Display for FormatZeroResponseCode
sourceimpl Error for FormatZeroResponseCode
impl Error for FormatZeroResponseCode
1.30.0 · sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
The lower-level source of this error, if any. Read more
sourcefn backtrace(&self) -> Option<&Backtrace>
fn backtrace(&self) -> Option<&Backtrace>
🔬 This is a nightly-only experimental API. (
backtrace)Returns a stack backtrace, if available, of where this error occurred. Read more
1.0.0 · sourcefn description(&self) -> &str
fn description(&self) -> &str
👎 Deprecated since 1.42.0:
use the Display impl or to_string()
sourceimpl PartialEq<FormatZeroResponseCode> for FormatZeroResponseCode
impl PartialEq<FormatZeroResponseCode> for FormatZeroResponseCode
sourcefn eq(&self, other: &FormatZeroResponseCode) -> bool
fn eq(&self, other: &FormatZeroResponseCode) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &FormatZeroResponseCode) -> bool
fn ne(&self, other: &FormatZeroResponseCode) -> bool
This method tests for !=.
impl Copy for FormatZeroResponseCode
impl StructuralPartialEq for FormatZeroResponseCode