pub struct ResponseCode(pub TSS2_RC);
Get a range of bits.
Set a range of bits.
Formats the value using the given formatter.
Read more
Get a single bit.
Set a single bit.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Drops the content pointed by this pointer and frees it.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.