#[repr(u8)]pub enum TpmFormatZeroWarning {
Show 28 variants
ContextGap = 1,
ObjectMemory = 2,
SessionMemory = 3,
Memory = 4,
SessionHandles = 5,
ObjectHandles = 6,
Locality = 7,
Yielded = 8,
Canceled = 9,
Testing = 10,
ReferenceH0 = 16,
ReferenceH1 = 17,
ReferenceH2 = 18,
ReferenceH3 = 19,
ReferenceH4 = 20,
ReferenceH5 = 21,
ReferenceH6 = 22,
ReferenceS0 = 24,
ReferenceS1 = 25,
ReferenceS2 = 26,
ReferenceS3 = 27,
ReferenceS4 = 28,
ReferenceS5 = 29,
ReferenceS6 = 30,
NvRate = 32,
Lockout = 33,
Retry = 34,
NvUnavailable = 35,
}Expand description
Enum representing TPM format zero warning.
Details
These are the values from the specification without the indicator that indicates that it is a TPM format zero warning (i.e. TPM2_RC_WARN).
Variants
ContextGap = 1
ObjectMemory = 2
SessionMemory = 3
Memory = 4
SessionHandles = 5
ObjectHandles = 6
Locality = 7
Yielded = 8
Canceled = 9
Testing = 10
ReferenceH0 = 16
ReferenceH1 = 17
ReferenceH2 = 18
ReferenceH3 = 19
ReferenceH4 = 20
ReferenceH5 = 21
ReferenceH6 = 22
ReferenceS0 = 24
ReferenceS1 = 25
ReferenceS2 = 26
ReferenceS3 = 27
ReferenceS4 = 28
ReferenceS5 = 29
ReferenceS6 = 30
NvRate = 32
Lockout = 33
Retry = 34