pub struct TpmFormatZeroErrorResponseCode { /* private fields */ }Expand description
Type representing the TPM format zero error response code.
Details
The error messages are short forms of the descriptions given in the specification
that describes return codes (see the
Part 2, Structures).
Sometimes these descriptions refers to fields within the structures described in the specification. When
a message contains such a description then the name of the of the field is surrounded with backticks
(e.g. authValue).
Implementations
Sourceimpl TpmFormatZeroErrorResponseCode
impl TpmFormatZeroErrorResponseCode
Sourcepub const fn error_number(&self) -> TpmFormatZeroError
pub const fn error_number(&self) -> TpmFormatZeroError
Returns the error number associated with the TPM format zero return code.