pub enum TpmHandle {
Pcr(PcrTpmHandle),
NvIndex(NvIndexTpmHandle),
HmacSession(HmacSessionTpmHandle),
LoadedSession(LoadedSessionTpmHandle),
PolicySession(PolicySessionTpmHandle),
SavedSession(SavedSessionTpmHandle),
Permanent(PermanentTpmHandle),
Transient(TransientTpmHandle),
Persistent(PersistentTpmHandle),
AttachedComponent(AttachedComponentTpmHandle),
}Expand description
Enum representing the different types of tpm handles of a TPM handle.
-
Details The TPM handles are used to reference shielded locations of various types within the TPM.
-
OBS Do not confuse the TpmHandles with the ESYS ObjectHandle.
Variants
Pcr(PcrTpmHandle)
NvIndex(NvIndexTpmHandle)
HmacSession(HmacSessionTpmHandle)
LoadedSession(LoadedSessionTpmHandle)
PolicySession(PolicySessionTpmHandle)
SavedSession(SavedSessionTpmHandle)
Permanent(PermanentTpmHandle)
Transient(TransientTpmHandle)
Persistent(PersistentTpmHandle)
AttachedComponent(AttachedComponentTpmHandle)