Struct tss_esapi::handles::AuthHandle
source · pub struct AuthHandle { /* private fields */ }Expand description
Module that contains the different types of handles that the ESAPI and the TPM uses in order to provide access to objects that was or has been created. ESYS Handles Auth handle
Represents an esys handle to resources that can be used for authentication.
Implementations
sourceimpl AuthHandle
impl AuthHandle
pub const Owner: AuthHandle = _
sourceimpl AuthHandle
impl AuthHandle
pub const Lockout: AuthHandle = _
sourceimpl AuthHandle
impl AuthHandle
pub const Endorsement: AuthHandle = _
sourceimpl AuthHandle
impl AuthHandle
pub const Platform: AuthHandle = _