Struct tss_esapi::handles::ObjectHandle
source · pub struct ObjectHandle { /* private fields */ }Expand description
The ObjectHandle is the general handle type and it wraps the ESYS_TR.
All the other more specific handle types can be converted into an ObjectHandle.
Implementations
sourceimpl ObjectHandle
impl ObjectHandle
pub const None: ObjectHandle = _
sourceimpl ObjectHandle
impl ObjectHandle
sourceimpl ObjectHandle
impl ObjectHandle
pub const Password: ObjectHandle = _
sourceimpl ObjectHandle
impl ObjectHandle
pub const Owner: ObjectHandle = _
sourceimpl ObjectHandle
impl ObjectHandle
pub const Lockout: ObjectHandle = _
sourceimpl ObjectHandle
impl ObjectHandle
pub const Endorsement: ObjectHandle = _
sourceimpl ObjectHandle
impl ObjectHandle
pub const Platform: ObjectHandle = _
sourceimpl ObjectHandle
impl ObjectHandle
pub const PlatformNv: ObjectHandle = _
sourceimpl ObjectHandle
impl ObjectHandle
pub const Null: ObjectHandle = _