Struct tss_esapi::handles::SessionHandle [−][src]
Session Handle
Represents an esys handle used for referencing session resources.
Implementations
impl SessionHandle[src]
impl SessionHandle[src]
pub const None: SessionHandle[src]
impl SessionHandle[src]
pub fn is_none(&self) -> bool[src]
Method that returns true if the handle corresponds to the None handle.
impl SessionHandle[src]
pub const Password: SessionHandle[src]