This module contains the different interface types defined in the TPM 2.0 specification.
Modules
Enums
- Arithmetic
Comparison - Arithmetic comparison operation for policy evaluation.
- YesNo
- Enum representing a yes or no.
This module contains the different interface types defined in the TPM 2.0 specification.