[−][src]Module tss_esapi::response_code
Module for error types
This module provides the error reporting framework for the crate. Error provenience is marked as a variant of an enum, distinguishing between errors coming from the TSS stack and those generated by this crate.
Structs
| FormatOneResponseCode | |
| FormatZeroResponseCode | |
| ResponseCode |
Enums
| Error | Main error type used by the crate to return issues with a method call. The value can either be a TSS-generated response code or a wrapper error - marking an issue caught within the wrapping layer. |
| Tss2ResponseCode | Rust native representation of the TSS2 response codes as defined in the spec. |
| Tss2ResponseCodeKind | Rust enum representation of TSS 2 error codes. |
| WrapperErrorKind | List of error types that might occur in the wrapper. |
Type Definitions
| Result |