Module structures

Module structures 

Re-exports

pub use self::pcr_slot::PcrSlot;
pub use self::pcr_select::PcrSelect;
pub use self::pcr_selection::PcrSelection;
pub use self::pcr_select_size::PcrSelectSize;
pub use self::digest_list::DigestList;
pub use self::digest_values::DigestValues;
pub use self::ecc_curves::EccCurveList;
pub use self::handle_list::HandleList;
pub use self::pcr_selection_list::PcrSelectionList;
pub use self::pcr_selection_list::PcrSelectionListBuilder;
pub use self::command_code_list::CommandCodeList;
pub use self::tagged_tpm_property_list::TaggedTpmPropertyList;
pub use algorithm_property_list::AlgorithmPropertyList;
pub use tagged_pcr_property_list::TaggedPcrPropertyList;
pub use self::command_code_attributes_list::CommandCodeAttributesList;

Modules

algorithm_property_list
command_code_attributes_list
command_code_list
digest_list
digest_values
ecc_curves
handle_list
pcr_select
pcr_select_size
pcr_selection
pcr_selection_list
pcr_slot
tagged_pcr_property_list
tagged_tpm_property_list

Structs

AlgorithmProperty
Strucutre for holding information describing an algorithm.
Attest
Type for holding attestation data
AttestBuffer
Attestation data buffer.
Auth
AuthTicket
CertifyInfo
This a struct holding the attested data for the command TPM2_Certify
ClockInfo
Information related to the internal temporal state of the TPM.
CommandAuditInfo
Structure holding the attested data for TPM2_GetCommandAuditDigest().
CreateKeyResult
CreatePrimaryKeyResult
CreationData
CreationInfo
Structure holding the attested data for TPM2_CertifyCreation()
CreationTicket
Rust native wrapper for TPMT_TK_CREATION objects.
Data
Digest
EcDaaScheme
Struct for holding the ECDAA scheme
EccParameter
EccPoint
Structure holding ecc point information
EccSignature
Type holding ECC signature information.
EncryptedSecret
HashAgile
HashScheme
Struct for holding the hash scheme
HashcheckTicket
HmacScheme
Struct for holding HMAC scheme.
IdObject
InitialValue
MaxBuffer
MaxNvBuffer
Name
Structure holding the data representing names
Nonce
NvCertifyInfo
This structure contains the Name and contents of the selected NV Index that is certified by TPM2_NV_Certify()
NvDigestCertifyInfo
This structure contains the Name and hash of the contents of the selected NV Index that is certified by TPM2_NV_Certify()
NvPublic
Representation of the public parameters of a non-volatile space allocation.
NvPublicBuilder
Builder for NvPublic.
Private
PrivateKeyRsa
PrivateVendorSpecific
PublicBuffer
Public data buffer.
PublicBuilder
A builder for the Public type.
PublicEccParameters
Structure holding the ECC specific parameters.
PublicEccParametersBuilder
Builder for PublicEccParameters.
PublicKeyRsa
PublicKeyedHashParameters
Keyed hash parameters
PublicRsaParameters
Structure holding the RSA specific parameters.
PublicRsaParametersBuilder
Builder for TPMS_RSA_PARMS values.
QuoteInfo
Structure holding the attested data for TPM2_Quote()
RsaExponent
Structure used to hold the value of a RSA exponent
RsaSignature
Type holding RSA signature information.
SensitiveBuffer
Sensitive data buffer.
SensitiveData
SessionAuditInfo
This type holds the attested data for TPM2_GetSessionAuditDigest()
SymmetricCipherParameters
Symmetric cipher parameters
SymmetricKey
TaggedPcrSelect
Type that holds information regarding what PCR slots that are associated with a specific pcr property tag.
TaggedProperty
Struct representing a tagged property
TimeAttestInfo
This type is holding attested data for the command TPM2_GetTime
TimeInfo
Structure holding the attestation for TPM2_GetTime() and TPM2_ReadClock().
Timeout
VerifiedTicket
Rust native wrapper for TPMT_TK_VERIFIED objects.
XorScheme
Struct for holding the xor scheme

Enums

AttestInfo
Enum that holds the different types of attest info.
CapabilityData
A representation of all the capabilites that can be associated with a TPM.
EccScheme
Enum representing the ecc scheme
KeyDerivationFunctionScheme
Enum representing the kdf scheme
KeyedHashScheme
Enum representing the keyed hash scheme.
Public
Enum representing the Public structure.
PublicParameters
Enum representing the public parameters structure.
RsaDecryptionScheme
Enum representing the rsa decryption scheme
RsaScheme
Enum representing the rsa scheme
Sensitive
Enum describing the Sensitive part of an object.
Signature
Enum representing a Signature
SignatureScheme
Full description of signature schemes.
SymmetricDefinition
Enum representing the symmetric algorithm definition.
SymmetricDefinitionObject
Enum representing the symmetric definition object.

Traits

Ticket