pub enum AttestInfo {
    Certify {
        info: CertifyInfo,
    },
    Quote {
        info: QuoteInfo,
    },
    SessionAudit {
        info: SessionAuditInfo,
    },
    CommandAudit {
        info: CommandAuditInfo,
    },
    Time {
        info: TimeAttestInfo,
    },
    Creation {
        info: CreationInfo,
    },
    Nv {
        info: NvCertifyInfo,
    },
}
Enum that holds the different types of attest info.

Details

This type does to some degree corresponds to the TPMU_ATTEST but with the TPM_ST_ATTEST selectore included.

Variants

Certify

Fields

Quote

Fields

info: QuoteInfo

SessionAudit

Fields

CommandAudit

Fields

Time

Fields

Creation

Fields

Nv

Fields