pub enum EccScheme {
EcDsa(HashScheme),
EcDh(HashScheme),
EcDaa(EcDaaScheme),
Sm2(HashScheme),
EcSchnorr(HashScheme),
EcMqv(HashScheme),
Null,
}Expand description
Enum representing the ecc scheme
Details
This corresponds to TPMT_ECC_SCHEME. This uses a subset of the TPMU_ASYM_SCHEME that has the TPMI_ALG_ECC_SCHEME as selector.
Variants
EcDsa(HashScheme)
EcDh(HashScheme)
EcDaa(EcDaaScheme)
Sm2(HashScheme)
EcSchnorr(HashScheme)
EcMqv(HashScheme)
Null
Implementations
Sourceimpl EccScheme
impl EccScheme
Sourcepub fn create(
ecc_scheme_algorithm: EccSchemeAlgorithm,
hashing_algorithm: Option<HashingAlgorithm>,
count: Option<u16>,
) -> Result<Self>
pub fn create( ecc_scheme_algorithm: EccSchemeAlgorithm, hashing_algorithm: Option<HashingAlgorithm>, count: Option<u16>, ) -> Result<Self>
Creates a EccScheme.
Arguments
ecc_scheme_algorithm - The ECC scheme algorithm.
hashing_algorithm - The hashing algorithm associated with some variants.
count - The counter value that is used between TPM2_Commit() and the sign
operation used in the EcDaa variant.
Errors
ParamMissing - If the algorithm indicates a variant that requires
one or more of the optional parameters and they have
not been provided.
InconsistentParams - If an optional parameter has been set but it is
not required.
pub fn algorithm(&self) -> EccSchemeAlgorithm