pub enum RsaDecryptionScheme {
RsaEs,
Oaep(HashScheme),
Null,
}Expand description
Variants
Implementations
Sourceimpl RsaDecryptionScheme
impl RsaDecryptionScheme
Sourcepub fn create(
rsa_decrypt_algorithm: RsaDecryptAlgorithm,
hashing_algorithm: Option<HashingAlgorithm>,
) -> Result<RsaDecryptionScheme>
pub fn create( rsa_decrypt_algorithm: RsaDecryptAlgorithm, hashing_algorithm: Option<HashingAlgorithm>, ) -> Result<RsaDecryptionScheme>
Creates a new rsa decrypt scheme.
Arguments
rsa_decrypt_algorithm - The RSA decryption algorithm.
hashing_algorithm - The hashing algorithm used in some variants of the scheme.
Errors
InconsistentParams - If a parameter has been provided when it is not required.
ParamsMissing - If a required parameter has not been provided.
Sourcepub fn algorithm(&self) -> RsaDecryptAlgorithm
pub fn algorithm(&self) -> RsaDecryptAlgorithm
Returns the rsa decrypt scheme algorithm