Enum tss_esapi::structures::pcr_select::PcrSlot [−][src]
This module contains necessary representations of the items belonging to the TPMS_PCR_SELECT structure.
The minimum number of octets allowed in a TPMS_PCR_SELECT.sizeOfSelect is not determined by the number of PCR implemented but by the number of PCR required by the platform-specific specification with which the TPM is compliant or by the implementer if not adhering to a platform-specific specification. Enum with the bit flag for each PCR slot.
Variants