pub struct PcrSelectionListBuilder { /* private fields */ }
A builder for the PcrSelectionList struct.

Implementations

Set the size of the pcr selection(sizeofSelect)

Arguments

size_of_select – The size that will be used for all selections(sizeofSelect).

Adds a selection associated with a specific HashingAlgorithm.

This function will not overwrite the values already associated with a specific HashingAlgorithm only update.

Arguments

hash_algorithm – The HashingAlgorithm associated with the pcr selection pcr_slots – The PCR slots in the selection.

Builds a PcrSelections with the values that have been provided.

If no size of select have been provided then it will be defaulted to to the most suitable with regard to TPM2_PCR_SELECT_MAX. This may not be the correct size for the current platform. The correct values can be obtained by querying the tpm for its capabilities.