SensitiveCreate

Struct SensitiveCreate 

pub struct SensitiveCreate { /* private fields */ }
Structure that defines the values to be placed in the sensitive area of a created object.

Details

This corresponds to the TPMS_SENSITIVE_CREATE structure.

There is a corresponding buffer type SensitiveCreateBuffer that holds the data in a marshalled form.

Implementations

Source

impl SensitiveCreate

pub const fn new(user_auth: Auth, data: SensitiveData) -> Self

Creates new SensitiveCreate.

pub const fn user_auth(&self) -> &Auth

Returns the user auth

pub const fn data(&self) -> &SensitiveData

Returns the sensitive data