Struct tss_esapi::structures::TaggedPcrSelect
source · [−]pub struct TaggedPcrSelect { /* private fields */ }Expand description
Type that holds information regarding what PCR slots that are associated with a specific pcr property tag.
This corresponds to the TPMS_TAGGED_PCR_SELECT.
Implementations
sourceimpl TaggedPcrSelect
impl TaggedPcrSelect
sourcepub fn create(
pcr_property_tag: PcrPropertyTag,
pcr_select_size: PcrSelectSize,
selected_pcr_slots: &[PcrSlot]
) -> Result<Self>
pub fn create(
pcr_property_tag: PcrPropertyTag,
pcr_select_size: PcrSelectSize,
selected_pcr_slots: &[PcrSlot]
) -> Result<Self>
Creates a new TaggedPcrSelect
sourcepub const fn pcr_property_tag(&self) -> PcrPropertyTag
pub const fn pcr_property_tag(&self) -> PcrPropertyTag
Returns the property identifier
sourcepub const fn size_of_select(&self) -> PcrSelectSize
pub const fn size_of_select(&self) -> PcrSelectSize
Returns the size of the select
NB! This is not the same as how many PcrSlot there are in the select, but rather how many octets are needed to hold the bit field which indicates what slots have the PcrPropertyTag property.