[−][src]Module tss_esapi::utils
Utility module
This module mostly contains helper elements meant to act as either wrappers around FFI-level
structs or builders for them, along with other convenience elements.
The naming structure usually takes the names inherited from the TSS spec and applies Rust
guidelines to them. Structures that are meant to act as builders have Builder appended to
type name. Unions are converted to Rust enums by dropping the TPMU qualifier and appending
Union.
Structs
| ObjectAttributes | |
| Signature | Rust native representation of an asymmetric signature. |
| Tpm2BPublicBuilder | Helper for building |
| TpmaSession | Rust native wrapper for session attributes objects. |
| TpmsContext | Rust native wrapper for |
| TpmsRsaParmsBuilder | Builder for |
| TpmtSymDefBuilder | Builder for |
| TpmtTkVerified | Rust native wrapper for |
Enums
| AsymSchemeUnion | Rust enum representation of |
| Hierarchy | Enum describing the object hierarchies in a TPM 2.0. |
| PublicIdUnion | Rust enum representation of |
| PublicParmsUnion | Rust enum representation of |
Functions
| get_rsa_public | Convenience method for generating |