Struct tss_esapi::utils::PcrBank [−][src]
Struct for holding PcrSlots and their corresponding values.
Implementations
impl PcrBank[src]
pub fn pcr_value(&self, pcr_slot: PcrSlot) -> Option<&Digest>[src]
Function for retrieving a pcr value corresponding to a pcr slot.
pub fn len(&self) -> usize[src]
Function for retrieiving the number of pcr slot values in the bank.
pub fn is_empty(&self) -> bool[src]
Returns true if there are no pcr slot values in the bank.