Struct tss_esapi::utils::PcrData [−][src]
Struct holding pcr banks and their associated hashing algorithm
Implementations
impl PcrData[src]
pub fn new(
tpml_pcr_selections: &TPML_PCR_SELECTION,
tpml_digests: &TPML_DIGEST
) -> Result<Self>[src]
tpml_pcr_selections: &TPML_PCR_SELECTION,
tpml_digests: &TPML_DIGEST
) -> Result<Self>
Contrustctor that creates a PcrData from tss types.
pub fn pcr_bank(&self, hashing_algorithm: HashingAlgorithm) -> Option<&PcrBank>[src]
Function for retriving a bank associated with the hashing_algorithm.
pub fn len(&self) -> usize[src]
Function for retrieving the number of banks in the data.
pub fn is_empty(&self) -> bool[src]
Returns true if there are no banks in the data.