Struct tss_esapi::utils::TpmsContext
source · pub struct TpmsContext { /* private fields */ }Expand description
Rust native wrapper for TPMS_CONTEXT objects.
This structure is intended to help with persisting object contexts. As the main reason for
saving the context of an object is to be able to re-use it later, on demand, a serializable
structure is most commonly needed. TpmsContext implements the Serialize and Deserialize
defined by serde.
Implementations
sourceimpl TpmsContext
impl TpmsContext
sourcepub fn context_blob(&self) -> &Vec<u8> ⓘ
pub fn context_blob(&self) -> &Vec<u8> ⓘ
Get a reference to the context_blob field