#[non_exhaustive]
pub enum NvOpenOptions {
    NewIndex {
        nv_public: NvPublic,
        auth_handle: NvAuth,
    },
    ExistingIndex {
        nv_index_handle: NvIndexTpmHandle,
        auth_handle: NvAuth,
    },
}
Options and flags which can be used to determine how a non-volatile storage index is opened.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

NewIndex

Fields

nv_public: NvPublic
auth_handle: NvAuth

Define a new NV space with given auth

ExistingIndex

Fields

nv_index_handle: NvIndexTpmHandle
auth_handle: NvAuth

Open the NV space at the given handle, with the given auth

Implementations

Opens a non-volatile storage index using the options specified by self

The non-volatile storage index may be used for reading or writing or both.