pub trait AssociatedHashingAlgorithm {
const TPM_DIGEST: HashingAlgorithm;
}Expand description
Provides the value of the digest used in this crate for the digest.
Required Associated Constants
Sourceconst TPM_DIGEST: HashingAlgorithm
const TPM_DIGEST: HashingAlgorithm
Value of the digest when interacting with the TPM.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".