pub struct CommandCodeAttributesBuilder { /* private fields */ }
A builder for CommandCodeAttributes

Implementations

Creates a new command code attributes builder.

Sets the command code to the specified value in the builder.

Sets the ‘nv’ bit in the builder.

Sets the ‘extensive’ bit in the builder.

Sets the ‘flushed’ bit in the builder.

Sets the three ‘c_handles’ bits in the builder.

Details

All bits besides the three first in the provided argument will be ignored.

Sets the ‘r_handle’ bit in the builder.

Sets the ‘V’(i.e. vendor specific) bit in the builder.

Builds the command code attributes

Errors

Returns an error if command index is not a command index associated with a CommandCode specified in the TPM specification.