pub struct CommandCodeAttributesBuilder { /* private fields */ }Expand description
A builder for CommandCodeAttributes
Implementations
sourceimpl CommandCodeAttributesBuilder
impl CommandCodeAttributesBuilder
sourcepub fn with_command_index(self, command_index: u16) -> Self
pub fn with_command_index(self, command_index: u16) -> Self
Sets the command code to the specified value in the builder.
sourcepub fn with_extensive(self, set: bool) -> Self
pub fn with_extensive(self, set: bool) -> Self
Sets the ‘extensive’ bit in the builder.
sourcepub fn with_flushed(self, set: bool) -> Self
pub fn with_flushed(self, set: bool) -> Self
Sets the ‘flushed’ bit in the builder.
sourcepub fn with_c_handles(self, value: u8) -> Self
pub fn with_c_handles(self, value: u8) -> Self
Sets the three ‘c_handles’ bits in the builder.
Details
All bits besides the three first in the provided argument will be ignored.
sourcepub fn with_r_handle(self, set: bool) -> Self
pub fn with_r_handle(self, set: bool) -> Self
Sets the ‘r_handle’ bit in the builder.
sourcepub fn with_vendor_specific(self, set: bool) -> Self
pub fn with_vendor_specific(self, set: bool) -> Self
Sets the ‘V’(i.e. vendor specific) bit in the builder.
sourcepub fn build(self) -> Result<CommandCodeAttributes>
pub fn build(self) -> Result<CommandCodeAttributes>
Builds the command code attributes
Errors
Returns an error if command index is not a command index associated with a CommandCode specified in the TPM specification.