Struct tss_esapi::attributes::object::ObjectAttributes
source · [−]pub struct ObjectAttributes(pub TPMA_OBJECT);Expand description
Bitfield representing the object attributes.
Tuple Fields
0: TPMA_OBJECTImplementations
sourceimpl ObjectAttributes
impl ObjectAttributes
pub fn fixed_tpm(&self) -> bool
pub fn st_clear(&self) -> bool
pub fn fixed_parent(&self) -> bool
pub fn sensitive_data_origin(&self) -> bool
pub fn user_with_auth(&self) -> bool
pub fn admin_with_policy(&self) -> bool
pub fn no_da(&self) -> bool
pub fn encrypted_duplication(&self) -> bool
pub fn restricted(&self) -> bool
pub fn decrypt(&self) -> bool
pub fn sign_encrypt(&self) -> bool
pub fn x509_sign(&self) -> bool
sourceimpl ObjectAttributes
impl ObjectAttributes
sourcepub fn new_fixed_parent_key() -> Self
pub fn new_fixed_parent_key() -> Self
Function for creating attributes for a fixed parent key object.
sourcepub fn new_fixed_signing_key() -> Self
pub fn new_fixed_signing_key() -> Self
Function for creating attributes for a fixed signing key object.
sourcepub const fn builder() -> ObjectAttributesBuilder
pub const fn builder() -> ObjectAttributesBuilder
Get a builder for the structure