pub struct ObjectAttributesBuilder { /* private fields */ }
A builder for ObjectAttributes

Implementations

Creates an new ObjectAttributes builder.

Controls the fixed tpm attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the st clear attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the fixed parent attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the sensitive data origin attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the user with auth attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the admin with policy attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the no da attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the encrypted duplication attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the restricted attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the decrypt attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the sign/encrypt attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Controls the X509 sign attribute

Arguments
  • set - true indicates that the attribute should have the value SET. falseindicates that the attribute should have the value CLEAR.

Builds the nv index attributes.

Errors

Returns an error if some attributes are missing or are in conflict with each other.