This module contains both the constants defined in the TSS specification (tss module) but also the internal representation of the TSS constants.
Re-exports
pub use capabilities::CapabilityType;pub use command_code::CommandCode;pub use ecc::EccCurveIdentifier;pub use nv_index_type::NvIndexType;pub use pcr_property_tag::PcrPropertyTag;pub use property_tag::PropertyTag;pub use response_code::ResponseCode;pub use response_code::Tss2ResponseCode;pub use response_code::Tss2ResponseCodeKind;pub use session_type::SessionType;pub use startup_type::StartupType;pub use structure_tags::StructureTag;
Modules
- capabilities
- Representation of the constants defined in the Constants -> TPM_CAP section of the specification
- command_
code - Representation of the constants defined in Constants -> TPM_CC section of the specification.
- ecc
- Representation of the constants defined in Constants -> TPM_ECC_CURVE section of the specification.
- nv_
index_ type - Representation of the constants defined in the NV Storage -> TPM_NT section of the specification
- pcr_
property_ tag - Representation of the constants defined in Constants -> TPM_PT_PCR section of the specification.
- property_
tag - Representation of the constants defined in the Constants -> TPM_PT section of the specification
- response_
code - Representation of the return code TSS2_RC (TPM_RC) Module for error types
- session_
type - Representation of the constants defined in the Constants -> TPM_SE section of the specification
- startup_
type - Representation of the constants defined in the Constants -> TPM_SU section of the specification
- structure_
tags - Representation of the constants defined in the Constants -> TPM_ST section of the specification
- tss
- The constants defined in the TSS specification. Exposes the constants form the TSS header.