Skip to main content Module error Copy item path Source BaseReturnCode Struct representing the TSS base response code EsapiReturnCode struct representing the error codes generated by the ESAPI layer
in TSS. FapiReturnCode Enum representing the error codes generated by the FAPI layer
in TSS. MuapiReturnCode Enum representing the error return codes generated by the MUAPI layer
in TSS. SapiReturnCode Enum representing the error codes generated by the SAPI layer
in TSS. TctiReturnCode Enum representing the TSS base return code constants. TpmFormatOneResponseCode Type representing the TPM format one response code. TpmFormatZeroErrorResponseCode Type representing the TPM format zero error
response code. TpmFormatZeroWarningResponseCode Type representing the TPM format zero warning
response code. ArgumentNumber Enum representing the type of argument with which
the format one tpm response code is associated with. Error Main error type used by the crate to return issues with a method call. The value can either be
a TSS-generated response code or a wrapper error - marking an issue caught within the wrapping
layer. ReturnCode Enum representing return codes and response codes
from the TSS and the TPM that indicates an error. TpmFormatZeroResponseCode Enum representing the TPM format zero response code. TpmResponseCode Enum representing an TPM response code. WrapperErrorKind List of error types that might occur in the wrapper. Result