Struct tss_esapi::handles::ObjectHandle[][src]

pub struct ObjectHandle { /* fields omitted */ }

The ObjectHandle is the general handle type and it wraps the ESYS_TR.

All the other more specific handle types can be converted into an ObjectHandle.

Implementations

impl ObjectHandle[src]

pub fn value(&self) -> u32[src]

impl ObjectHandle[src]

impl ObjectHandle[src]

pub fn is_none(&self) -> bool[src]

Method that returns true if the handle corresponds to the None handle.

impl ObjectHandle[src]

impl ObjectHandle[src]

impl ObjectHandle[src]

impl ObjectHandle[src]

impl ObjectHandle[src]

impl ObjectHandle[src]

impl ObjectHandle[src]