Struct tss_esapi::handles::ObjectHandle [−][src]
The ObjectHandle is the general handle type and it wraps the ESYS_TR.
All the other more specific handle types can be converted into an ObjectHandle.
Implementations
impl ObjectHandle[src]
impl ObjectHandle[src]
pub const None: ObjectHandle[src]
impl ObjectHandle[src]
pub fn is_none(&self) -> bool[src]
Method that returns true if the handle corresponds to the None handle.
impl ObjectHandle[src]
pub const Password: ObjectHandle[src]
impl ObjectHandle[src]
pub const Owner: ObjectHandle[src]
impl ObjectHandle[src]
pub const Lockout: ObjectHandle[src]
impl ObjectHandle[src]
pub const Endorsement: ObjectHandle[src]
impl ObjectHandle[src]
pub const Platform: ObjectHandle[src]
impl ObjectHandle[src]
pub const PlatformNv: ObjectHandle[src]
impl ObjectHandle[src]
pub const Null: ObjectHandle[src]