Re-exports
pub use self::pcr_slot::PcrSlot;pub use self::pcr_select::PcrSelect;pub use self::pcr_selection::PcrSelection;pub use self::pcr_select_size::PcrSelectSize;pub use self::digest_list::DigestList;pub use self::digest_values::DigestValues;pub use self::ecc_curves::EccCurveList;pub use self::handle_list::HandleList;pub use self::pcr_selection_list::PcrSelectionList;pub use self::pcr_selection_list::PcrSelectionListBuilder;pub use self::command_code_list::CommandCodeList;pub use self::tagged_tpm_property_list::TaggedTpmPropertyList;pub use algorithm_property_list::AlgorithmPropertyList;pub use tagged_pcr_property_list::TaggedPcrPropertyList;pub use self::command_code_attributes_list::CommandCodeAttributesList;
Modules
- algorithm_
property_ list - command_
code_ attributes_ list - command_
code_ list - digest_
list - digest_
values - ecc_
curves - handle_
list - pcr_
select - pcr_
select_ size - pcr_
selection - pcr_
selection_ list - pcr_
slot - tagged_
pcr_ property_ list - tagged_
tpm_ property_ list
Structs
- Algorithm
Property - Strucutre for holding information describing an algorithm.
- Attest
- Type for holding attestation data
- Attest
Buffer - Attestation data buffer.
- Auth
- Auth
Ticket - Certify
Info - This a struct holding the attested data for the command TPM2_Certify
- Clock
Info - Information related to the internal temporal state of the TPM.
- Command
Audit Info - Structure holding the attested data for TPM2_GetCommandAuditDigest().
- Create
KeyResult - Create
Primary KeyResult - Creation
Data - Creation
Info - Structure holding the attested data for TPM2_CertifyCreation()
- Creation
Ticket - Rust native wrapper for
TPMT_TK_CREATIONobjects. - Data
- Digest
- EcDaa
Scheme - Struct for holding the ECDAA scheme
- EccParameter
- EccPoint
- Structure holding ecc point information
- EccSignature
- Type holding ECC signature information.
- Encrypted
Secret - Hash
Agile - Hash
Scheme - Struct for holding the hash scheme
- Hashcheck
Ticket - Hmac
Scheme - Struct for holding HMAC scheme.
- IdObject
- Initial
Value - MaxBuffer
- MaxNv
Buffer - Name
- Structure holding the data representing names
- Nonce
- NvCertify
Info - This structure contains the Name and contents of the selected NV Index that is certified by TPM2_NV_Certify()
- NvDigest
Certify Info - This structure contains the Name and hash of the contents of the selected NV Index that is certified by TPM2_NV_Certify()
- NvPublic
- Representation of the public parameters of a non-volatile space allocation.
- NvPublic
Builder - Builder for NvPublic.
- Private
- Private
KeyRsa - Private
Vendor Specific - Public
Buffer - Public data buffer.
- Public
Builder - A builder for the Public type.
- Public
EccParameters - Structure holding the ECC specific parameters.
- Public
EccParameters Builder - Builder for PublicEccParameters.
- Public
KeyRsa - Public
Keyed Hash Parameters - Keyed hash parameters
- Public
RsaParameters - Structure holding the RSA specific parameters.
- Public
RsaParameters Builder - Builder for
TPMS_RSA_PARMSvalues. - Quote
Info - Structure holding the attested data for TPM2_Quote()
- RsaExponent
- Structure used to hold the value of a RSA exponent
- RsaSignature
- Type holding RSA signature information.
- Sensitive
Buffer - Sensitive data buffer.
- Sensitive
Data - Session
Audit Info - This type holds the attested data for TPM2_GetSessionAuditDigest()
- Symmetric
Cipher Parameters - Symmetric cipher parameters
- Symmetric
Key - Tagged
PcrSelect - Type that holds information regarding what PCR slots that are associated with a specific pcr property tag.
- Tagged
Property - Struct representing a tagged property
- Time
Attest Info - This type is holding attested data for the command TPM2_GetTime
- Time
Info - Structure holding the attestation for TPM2_GetTime() and TPM2_ReadClock().
- Timeout
- Verified
Ticket - Rust native wrapper for
TPMT_TK_VERIFIEDobjects. - XorScheme
- Struct for holding the xor scheme
Enums
- Attest
Info - Enum that holds the different types of attest info.
- Capability
Data - A representation of all the capabilites that can be associated with a TPM.
- EccScheme
- Enum representing the ecc scheme
- KeyDerivation
Function Scheme - Enum representing the kdf scheme
- Keyed
Hash Scheme - Enum representing the keyed hash scheme.
- Public
- Enum representing the Public structure.
- Public
Parameters - Enum representing the public parameters structure.
- RsaDecryption
Scheme - Enum representing the rsa decryption scheme
- RsaScheme
- Enum representing the rsa scheme
- Sensitive
- Enum describing the Sensitive part of an object.
- Signature
- Enum representing a Signature
- Signature
Scheme - Full description of signature schemes.
- Symmetric
Definition - Enum representing the symmetric algorithm definition.
- Symmetric
Definition Object - Enum representing the symmetric definition object.