Enum tss_esapi::structures::AttestInfo
source · [−]pub enum AttestInfo {
Certify {
info: CertifyInfo,
},
Quote {
info: QuoteInfo,
},
SessionAudit {
info: SessionAuditInfo,
},
CommandAudit {
info: CommandAuditInfo,
},
Time {
info: TimeAttestInfo,
},
Creation {
info: CreationInfo,
},
Nv {
info: NvCertifyInfo,
},
}Expand description
Enum that holds the different types of attest info.
Details
This type does to some degree corresponds to the TPMU_ATTEST but with the TPM_ST_ATTEST selectore included.
Variants
Certify
Fields
info: CertifyInfoQuote
Fields
info: QuoteInfoSessionAudit
Fields
info: SessionAuditInfoCommandAudit
Fields
info: CommandAuditInfoTime
Fields
info: TimeAttestInfoCreation
Fields
info: CreationInfoNv
Fields
info: NvCertifyInfoTrait Implementations
sourceimpl Clone for AttestInfo
impl Clone for AttestInfo
sourcefn clone(&self) -> AttestInfo
fn clone(&self) -> AttestInfo
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for AttestInfo
impl Debug for AttestInfo
sourceimpl From<AttestInfo> for TPMU_ATTEST
impl From<AttestInfo> for TPMU_ATTEST
sourcefn from(attest_info: AttestInfo) -> Self
fn from(attest_info: AttestInfo) -> Self
Performs the conversion.