Enum tss_esapi::structures::RsaScheme
source · pub enum RsaScheme {
RsaSsa(HashScheme),
RsaEs,
RsaPss(HashScheme),
Oaep(HashScheme),
Null,
}Expand description
Enum representing the rsa scheme
Details
This corresponds to TPMT_RSA_SCHEME. This uses a subset of the TPMU_ASYM_SCHEME that has the TPMI_ALG_RSA_SCHEME as selector.
Variants
Implementations
sourceimpl RsaScheme
impl RsaScheme
sourcepub fn create(
rsa_scheme_algorithm: RsaSchemeAlgorithm,
hashing_algorithm: Option<HashingAlgorithm>
) -> Result<RsaScheme>
pub fn create(
rsa_scheme_algorithm: RsaSchemeAlgorithm,
hashing_algorithm: Option<HashingAlgorithm>
) -> Result<RsaScheme>
Creates a new RsaScheme
Errors
InconsistentParamserror will be returned if no hashing algorithm is provided when creating RSA scheme of type RSA SSA, RSA PSS and OAEP or if a hashing algorithm is provided when creating a RSA scheme
sourcepub fn algorithm(&self) -> RsaSchemeAlgorithm
pub fn algorithm(&self) -> RsaSchemeAlgorithm
Returns the rsa scheme algorithm