pub struct PublicBuilder { /* private fields */ }
A builder for the Public type.

Implementations

Creates a new PublicBuilder

Details

Builds the Public type using the provided parameters. Parameters associated with other algorithms then the provided public algorithm will be ignored.

Adds the public algorithm for the Public structure to the builder.

Adds the attributes of the Public structure to the builder

Adds the name hash algorithm for the Public strucutre to the builder.

Adds the auth policy for the Public strucutre to the builder

Adds the RSA parameters for the Public structure to the builder.

Details

This is required if the public algorithm is set to Rsa.

Adds the RSA unique identifier for the Public structure to the builder.

Details

This is required if the public algorithm is set to Rsa.

The unique identifier is the public key.

Adds the keyed hash parameters for the Public structure to the builder.

Details

This is required if the public algorithm is set to KeyedHash.

Adds the keyed hash unique identifier for the Public structure to the builder.

Details

This is required if the public algorithm is set to KeyedHash.

Adds the ECC parameters for the Public structure to the builder.

Details

This is required if the public algorithm is set to Ecc.

Adds the ECC unique identifier for the Public structure to the builder.

Details

This is required if the public algorithm is set to Ecc.

The unique identifier is a ecc point.

Adds the symmetric cipher parameters for the Public structure to the builder.

Details

This is required if the public algorithm is set to SymCipher.

Adds the symmetric cipher unique identifier for the Public structure to the builder.

Details

This is required if the public algorithm is set to SymCipher.

Builds the Public structure.

Errors

Will return error if the public algorithm, object attributes or name hashing algorithm have not been set or if the parameters and unique identifier does not match the selected public algorithm.