Struct tss_esapi::structures::PublicBuilder
source · [−]pub struct PublicBuilder { /* private fields */ }Expand description
A builder for the Public type.
Implementations
sourceimpl PublicBuilder
impl PublicBuilder
sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new PublicBuilder
Details
Builds the Public type using the provided parameters. Parameters associated with other algorithms then the provided public algorithm will be ignored.
sourcepub const fn with_public_algorithm(
self,
public_algorithm: PublicAlgorithm
) -> Self
pub const fn with_public_algorithm(
self,
public_algorithm: PublicAlgorithm
) -> Self
Adds the public algorithm for the Public structure to the builder.
sourcepub const fn with_object_attributes(
self,
object_attributes: ObjectAttributes
) -> Self
pub const fn with_object_attributes(
self,
object_attributes: ObjectAttributes
) -> Self
Adds the attributes of the Public structure to the builder
sourcepub const fn with_name_hashing_algorithm(
self,
name_hashing_algorithm: HashingAlgorithm
) -> Self
pub const fn with_name_hashing_algorithm(
self,
name_hashing_algorithm: HashingAlgorithm
) -> Self
Adds the name hash algorithm for the Public strucutre to the builder.
sourcepub fn with_auth_policy(self, auth_policy: Digest) -> Self
pub fn with_auth_policy(self, auth_policy: Digest) -> Self
Adds the auth policy for the Public strucutre to the builder
sourcepub fn with_rsa_parameters(self, rsa_parameters: PublicRsaParameters) -> Self
pub fn with_rsa_parameters(self, rsa_parameters: PublicRsaParameters) -> Self
sourcepub fn with_rsa_unique_identifier(
self,
rsa_unique_identifier: PublicKeyRsa
) -> Self
pub fn with_rsa_unique_identifier(
self,
rsa_unique_identifier: PublicKeyRsa
) -> Self
sourcepub fn with_keyed_hash_parameters(
self,
keyed_hash_parameters: PublicKeyedHashParameters
) -> Self
pub fn with_keyed_hash_parameters(
self,
keyed_hash_parameters: PublicKeyedHashParameters
) -> Self
sourcepub fn with_keyed_hash_unique_identifier(
self,
keyed_hash_unique_identifier: Digest
) -> Self
pub fn with_keyed_hash_unique_identifier(
self,
keyed_hash_unique_identifier: Digest
) -> Self
sourcepub const fn with_ecc_parameters(
self,
ecc_parameters: PublicEccParameters
) -> Self
pub const fn with_ecc_parameters(
self,
ecc_parameters: PublicEccParameters
) -> Self
sourcepub fn with_ecc_unique_identifier(self, ecc_unique_identifier: EccPoint) -> Self
pub fn with_ecc_unique_identifier(self, ecc_unique_identifier: EccPoint) -> Self
sourcepub const fn with_symmetric_cipher_parameters(
self,
symmetric_cipher_parameters: SymmetricCipherParameters
) -> Self
pub const fn with_symmetric_cipher_parameters(
self,
symmetric_cipher_parameters: SymmetricCipherParameters
) -> Self
sourcepub fn with_symmetric_cipher_unique_identifier(
self,
symmetric_cipher_unique_identifier: Digest
) -> Self
pub fn with_symmetric_cipher_unique_identifier(
self,
symmetric_cipher_unique_identifier: Digest
) -> Self