pub struct RsaExponent { /* private fields */ }
Structure used to hold the value of a RSA exponent

Implementations

Empty exponent (internal value is 0), which is treated by TPMs as a shorthand for the default value (2^16 + 1).

Function for creating a new RsaExponent

Warning

Will not check whether the value is a valid exponent for RSA.

Errors

Will return an error if the value passed into the function is not a valid RSA exponent.

Method that returns the value of the rsa exponent.

👎 Deprecated since 7.0.1:

TPMs are only mandated to support 0 as an exponent, with support for and checking of other values being done differently by each manufacturer. See discussion here: https://github.com/parallaxsecond/rust-tss-esapi/pull/332

No-op. Does not check whether the value is a valid exponent for RSA.