Struct tss_esapi::structures::RsaExponent
source · [−]pub struct RsaExponent { /* private fields */ }Expand description
Structure used to hold the value of a RSA exponent
Implementations
sourceimpl RsaExponent
impl RsaExponent
sourcepub const ZERO_EXPONENT: Self = RsaExponent { value: 0 }
pub const ZERO_EXPONENT: Self = RsaExponent { value: 0 }
Empty exponent (internal value is 0), which is treated by TPMs as a shorthand for the default value (2^16 + 1).
sourcepub fn is_valid(_: u32) -> bool
👎 Deprecated since 7.0.1: TPMs are only mandated to support 0 as an exponent, with support for and checking of other values being done differently by each manufacturer. See discussion here: https://github.com/parallaxsecond/rust-tss-esapi/pull/332
pub fn is_valid(_: u32) -> bool
TPMs are only mandated to support 0 as an exponent, with support for and checking of other values being done differently by each manufacturer. See discussion here: https://github.com/parallaxsecond/rust-tss-esapi/pull/332
No-op. Does not check whether the value is a valid exponent for RSA.