pub struct RsaExponent { /* private fields */ }
Structure used to hold the value of a RSA exponent

Implementations

Empty exponent (internal value is 0), which is treated by TPMs as a shorthand for the default value (2^16 + 1).

Function for creating a new RsaExponent

Errors

Will return an error if the value passed into the function is not a valid RSA exponent.

Method that returns the value of the rsa exponent.

Function for checking if a value is valid rsa exponent.