Struct tss_esapi::structures::RsaExponent
source · [−]pub struct RsaExponent { /* private fields */ }Expand description
Structure used to hold the value of a RSA exponent
Implementations
sourceimpl RsaExponent
impl RsaExponent
sourcepub const ZERO_EXPONENT: Self
pub const ZERO_EXPONENT: Self
Empty exponent (internal value is 0), which is treated by TPMs as a shorthand for the default value (2^16 + 1).