pub struct SavedTpmContext { /* private fields */ }Expand description
Structure holding the content of a TPM context.
Details
This object can be serialized and deserialized
using serde if the serde feature is enabled.
Implementations
Sourceimpl SavedTpmContext
impl SavedTpmContext
Sourcepub const fn sequence(&self) -> u64
pub const fn sequence(&self) -> u64
The sequence parameter
Details
“The sequence parameter is used to differentiate the contexts and to allow the TPM to create a different encryption key for each context.”
Sourcepub const fn saved_handle(&self) -> Saved
pub const fn saved_handle(&self) -> Saved
The saved handle.
Sourcepub fn context_blob(&self) -> &TpmContextData
pub fn context_blob(&self) -> &TpmContextData
The context blob.
Details
“This is the hierarchy (Hierarchy) for the saved context and determines the proof value used in the construction of the encryption and integrity values for the context. For session and sequence contexts, the hierarchy is Hierarchy::Null. The hierarchy for a transient object may be Hierarchy::Null but it is not required.”