pub struct SensitiveCreate { /* private fields */ }Expand description
Structure that defines the values to be placed in the sensitive area of a created object.
Details
This corresponds to the TPMS_SENSITIVE_CREATE structure.
There is a corresponding buffer type SensitiveCreateBuffer that holds the data in a marshalled form.
Implementations
Sourceimpl SensitiveCreate
impl SensitiveCreate
Sourcepub const fn new(user_auth: Auth, data: SensitiveData) -> Self
pub const fn new(user_auth: Auth, data: SensitiveData) -> Self
Creates new SensitiveCreate.
Sourcepub const fn data(&self) -> &SensitiveData
pub const fn data(&self) -> &SensitiveData
Returns the sensitive data