pub enum PublicKey {
Rsa(Vec<u8>),
Ecc {
x: Vec<u8>,
y: Vec<u8>,
},
}Expand description
Container for public key values
Variants
Rsa(Vec<u8>)
RSA public modulus (see 27.5.3.4 in the Architecture spec)
This is the value extracted from the unique part of TPMT_PUBLIC.
The exponent is not included here as the expectation is that the
exponent is always pinned to 65537 (2^16 + 1).
The modulus is in Big-Endian format.
Ecc
Public elliptic curve point (see 27.5.3.5 in the Architecture spec)
The x and y coordinates are given uncompressed.